'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_OES_blend_subtract'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_OES_blend_subtract',error_checker=_errors._error_checker)
GL_BLEND_EQUATION_OES=_C('GL_BLEND_EQUATION_OES',0x8009)
GL_FUNC_ADD_OES=_C('GL_FUNC_ADD_OES',0x8006)
GL_FUNC_REVERSE_SUBTRACT_OES=_C('GL_FUNC_REVERSE_SUBTRACT_OES',0x800B)
GL_FUNC_SUBTRACT_OES=_C('GL_FUNC_SUBTRACT_OES',0x800A)
@_f
@_p.types(None,_cs.GLenum)
def glBlendEquationOES(mode):pass
